@@ -1,9 +1,20 @@
 # HEADER ####################################################
-# This is file  spam/R/kronecker.R.                         #
-# This file is part of the spam package,                    #
-#      http://www.math.uzh.ch/furrer/software/spam/         #
+# This is file spam/R/kronecker.R.                          #
+# It is part of the R package spam,                         #
+#  --> https://CRAN.R-project.org/package=spam              #
+#  --> https://CRAN.R-project.org/package=spam64            #
+#  --> https://git.math.uzh.ch/reinhard.furrer/spam         #
 # by Reinhard Furrer [aut, cre], Florian Gerber [ctb],      #
-#    Daniel Gerber [ctb], Kaspar Moesinger [ctb]            #
+#    Daniel Gerber [ctb], Kaspar Moesinger [ctb],           #
+#    Youcef Saad [ctb] (SPARSEKIT),                         #
+#    Esmond G. Ng [ctb] (Fortran Cholesky routines),        #
+#    Barry W. Peyton [ctb] (Fortran Cholesky routines),     #
+#    Joseph W.H. Liu [ctb] (Fortran Cholesky routines),     #
+#    Alan D. George [ctb] (Fortran Cholesky routines),      #
+#    Esmond G. Ng [ctb] (Fortran Cholesky routines),        #
+#    Barry W. Peyton [ctb] (Fortran Cholesky routines),     #
+#    Joseph W.H. Liu [ctb] (Fortran Cholesky routines),     #
+#    Alan D. George [ctb] (Fortran Cholesky routines)       #
 # HEADER END ################################################
 
 
@@ -15,7 +26,7 @@ kronecker.spam <- function(X,Y,FUN = "*", make.dimnames = FALSE, ...)
 {
     ## print("1")
     if(getOption("spam.force64"))
-        SS <- .format64
+        SS <- .format64()
     else
         SS <- .format32
     
@@ -31,7 +42,7 @@ kronecker.spam <- function(X,Y,FUN = "*", make.dimnames = FALSE, ...)
     Xcol <- X@colindices
     Xrow <- X@rowpointers
     if(.format.spam(X)$package == "spam64")
-        SS <- .format64
+        SS <- .format64()
   }else if (is.vector(X)){
     Xentries <- X
     Xcol <- rep.int(as.integer(1),lenx)
@@ -50,7 +61,7 @@ kronecker.spam <- function(X,Y,FUN = "*", make.dimnames = FALSE, ...)
     Ycol <- Y@colindices
     Yrow <- Y@rowpointers
     if(.format.spam(Y)$package == "spam64")
-        SS <- .format64
+        SS <- .format64()
   } else if (is.vector(Y)){
     Yentries <- Y
     Ycol <- rep.int(as.integer(1),leny)
